#
# Script version 1.0
#
# Version history:
#  1.0  First version of this script
#

require 'base_routing'
require 'txnx_shaken'

# This script routes calls in the mostsimple fashion. The behavior is the same as routing without ruby scripts
# with the addition of nap availability.
#
# Routing is in the following order:
#
# * Matching: BaseRouting.route_match
#   * :call_field_name => :called - Match the called number of the call to a route.
#   * :call_field_name => :calling - Match the calling number of the call to a route.
#   * :call_field_name => :nap - Match the nap of the call to a route.
#   * :call_field_name => :called, :route_field_name => :remapped_called - Remap the called
#     number for the outgoing call.
#   * :call_field_name => :calling, :route_field_name => :remapped_calling - Remap the calling
#     number for the outgoing call.
#   * :call_field_name => :nap, :route_field_name => :remapped_nap - Remap the nap for the outgoing call.
#     This means setting the destination nap for the route.
#


class TxnxRouting < BaseRouting
  include TxnxShaken

  before_filter :method => :txnx_shaken

  route_match :call_field_name => :called
  route_match :call_field_name => :calling
  route_match :call_field_name => :nap
  route_remap :call_field_name => :called, :route_field_name => :remapped_called
  route_remap :call_field_name => :calling, :route_field_name => :remapped_calling
  route_remap :call_field_name => :nap, :route_field_name => :remapped_nap
  route_order :route_field_name => :priority
end

@@routing = TxnxRouting.new

def init_routes(routes)
  @@routing.init routes
end

def route(call, nap_list)
  @@routing.route call, nap_list
end