#
# Script version 1.0
#
# Version history:
#  1.0  First version of this script
#
# This before-matching filter is used to test some ideas.
#
#
# In order to use this module, follow the steps below:
# 1- Add the "require 'txnx_shaken'" statement at the top of the main
#    script.
# 2- Add the "include TxnxShaken" statement in the main routing class.
# 3- Add the filter "before_filter :method => :txnx_shaken" in the
#    main routing class.
#

module TxnxShaken
  def init_txnx_shaken(params)
    params
  end

  def txnx_shaken(params)
    call = params[:call]
    contacts = params[:contacts]

    # Added this to support request_uri 3xx routing
    call[:request_uri_forward_enabled] = 'true'

    # Verify if this routing query is for an incoming call
    # To find this, we look at the contact index (it should be zero)
    if (contacts[:index].to_i == 0)
      log_trace :always, "TxnxShaken: INVITE"

      # Add P-Source-Device header
      custom_header = "P-Source-Device:" + call[:sip_remote_addr]
      
      # Extract Identity header
      sip_header = call[:sip_header]
      if !sip_header.nil?
        headers = sip_header.split(/\n+/)
        headers.each do |header|
          if header.match(/^Identity:/)
            # Save Identity header to pass to redirect logic
            params[:user_context] = { "identity_header" => header }
            # Add Identity header to pass to OSPrey
            custom_header += "\n" + header
            break
          end
        end
      end

      # Pass custom headers to OSPrey
      call[:sip_header] = custom_header

      # Replace current routes with a list of redirect routes with priority
      newroutes = []
      nap_lists = params[:naps]
      nap_lists.each do |nap_list, nap_info|
        if nap_info[:server_type] == "REDIRECT"
          newroutes << { :name => nap_info[:name], :remapped_nap => nap_info[:name] , :priority => nap_info[:priority] }
        end
      end
      params[:routes] = newroutes
    else
      log_trace :always, "TxnxShaken: REDIRECT"

      # Get Identity header
      identity_header = nil
      context = params[:user_context]
      if !(context.nil? || context.empty?)
        identity_header = context[:identity_header]
      end
      if identity_header.nil? || identity_header.empty?
        # Extract X-Identity header
        sip_header = call[:sip_header]
        if !sip_header.nil?
          headers = sip_header.split(/\n+/)
          headers.each do |header|
            if header.match(/^X-Identity:/)
             identity_header = header
              break
            end
          end
        end
      end

      # Add Identity header to pass to destination
      if !(identity_header.nil? || identity_header.empty?)
        call[:sip_header] = identity_header
      else
        call[:sip_header] = nil
      end
    end

    params[:call] = call

    params
  end
end